// Mozilla User Preferences

// DO NOT EDIT THIS FILE.
//
// If you make changes to this file while the application is running,
// the changes will be overwritten when the application exits.
//
// To change a preference value, you can either:
// - modify it via the UI (e.g. via about:config in the browser); or
// - set it within a user.js file in your profile.

user_pref("app.normandy.first_run", false);
user_pref("app.normandy.migrationsApplied", 12);
user_pref("app.normandy.user_id", "40f073f8-f68a-4523-bc8c-bdf1e6fe090a");
user_pref("app.update.lastUpdateTime.browser-cleanup-thumbnails", 0);
user_pref("app.update.lastUpdateTime.recipe-client-addon-run", 1713626624);
user_pref("app.update.lastUpdateTime.region-update-timer", 0);
user_pref("app.update.lastUpdateTime.rs-experiment-loader-timer", 1713626658);
user_pref("app.update.lastUpdateTime.xpi-signature-verification", 0);
user_pref("browser.bookmarks.addedImportButton", true);
user_pref("browser.cache.disk.capacity", 0);
user_pref("browser.cache.disk.enable", false);
user_pref("browser.cache.disk.filesystem_reported", 1);
user_pref("browser.cache.disk.smart_size.enabled", false);
user_pref("browser.cache.disk.smart_size.first_run", false);
user_pref("browser.cache.disk.smart_size.use_old_max", false);
user_pref("browser.contentblocking.category", "strict");
user_pref("browser.contextual-services.contextId", "{fbd630a0-ef4e-43b2-a011-c6c7bf0e3918}");
user_pref("browser.ctrlTab.previews", true);
user_pref("browser.download.viewableInternally.typeWasRegistered.avif", true);
user_pref("browser.download.viewableInternally.typeWasRegistered.webp", true);
user_pref("browser.laterrun.bookkeeping.profileCreationTime", 1713626622);
user_pref("browser.laterrun.bookkeeping.sessionCount", 1);
user_pref("browser.laterrun.enabled", true);
user_pref("browser.migration.version", 142);
user_pref("browser.newtabpage.activity-stream.impressionId", "{9a7d421f-9cc9-49db-9d91-ea7bb2a14087}");
user_pref("browser.newtabpage.storageVersion", 1);
user_pref("browser.pageActions.persistedActions", "{\"ids\":[\"bookmark\"],\"idsInUrlbar\":[\"bookmark\"],\"idsInUrlbarPreProton\":[],\"version\":1}");
user_pref("browser.pagethumbnails.storage_version", 3);
user_pref("browser.policies.applied", true);
user_pref("browser.proton.toolbar.version", 3);
user_pref("browser.region.update.updated", 1713626623);
user_pref("browser.safebrowsing.provider.mozilla.lastupdatetime", "1713626625175");
user_pref("browser.safebrowsing.provider.mozilla.nextupdatetime", "1713648225175");
user_pref("browser.search.region", "IE");
user_pref("browser.sessionstore.upgradeBackup.latestBuildID", "20240118164516");
user_pref("browser.shell.mostRecentDateSetAsDefault", "1713626658");
user_pref("browser.startup.couldRestoreSession.count", 2);
user_pref("browser.startup.homepage_override.buildID", "20240118164516");
user_pref("browser.startup.homepage_override.mstone", "122.0");
user_pref("browser.startup.lastColdStartupCheck", 1713626658);
user_pref("browser.tabs.drawInTitlebar", false);
user_pref("browser.topsites.contile.lastFetch", 1713626658);
user_pref("browser.translations.automaticallyPopup", false);
user_pref("browser.link.open_newwindow", 2);
user_pref("browser.uiCustomization.state", "{\"placements\":{\"widget-overflow-fixed-list\":[],\"unified-extensions-area\":[],\"nav-bar\":[\"back-button\",\"forward-button\",\"stop-reload-button\",\"customizableui-special-spring1\",\"urlbar-container\",\"customizableui-special-spring2\",\"save-to-pocket-button\",\"downloads-button\",\"fxa-toolbar-menu-button\",\"unified-extensions-button\"],\"toolbar-menubar\":[\"menubar-items\"],\"TabsToolbar\":[\"firefox-view-button\",\"tabbrowser-tabs\",\"new-tab-button\",\"alltabs-button\"],\"PersonalToolbar\":[\"import-button\",\"personal-bookmarks\"]},\"seen\":[\"save-to-pocket-button\",\"developer-button\"],\"dirtyAreaCache\":[\"nav-bar\",\"PersonalToolbar\",\"toolbar-menubar\",\"TabsToolbar\"],\"currentVersion\":20,\"newElementCount\":2}");
user_pref("browser.urlbar.placeholderName", "Google");
user_pref("browser.urlbar.quicksuggest.migrationVersion", 2);
user_pref("browser.urlbar.quicksuggest.scenario", "history");
user_pref("datareporting.policy.dataSubmissionPolicyAcceptedVersion", 2);
user_pref("datareporting.policy.dataSubmissionPolicyNotifiedTime", "1713626623704");
user_pref("distribution.iniFile.exists.appversion", "122.0");
user_pref("distribution.iniFile.exists.value", true);
user_pref("distribution.mint-001.bookmarksProcessed", true);
user_pref("doh-rollout.doneFirstRun", true);
user_pref("doh-rollout.home-region", "IE");
user_pref("dom.push.userAgentID", "722ebc83f8134258b6ed29575b1060e5");
user_pref("extensions.activeThemeID", "default-theme@mozilla.org");
user_pref("extensions.blocklist.pingCountVersion", 0);
user_pref("extensions.databaseSchema", 35);
user_pref("extensions.getAddons.cache.lastUpdate", 1713626659);
user_pref("extensions.getAddons.databaseSchema", 6);
user_pref("extensions.lastAppBuildId", "20240118164516");
user_pref("extensions.lastAppVersion", "122.0");
user_pref("extensions.lastPlatformVersion", "122.0");
user_pref("extensions.pendingOperations", false);
user_pref("extensions.pictureinpicture.enable_picture_in_picture_overrides", true);
user_pref("extensions.systemAddonSet", "{\"schema\":1,\"addons\":{}}");
user_pref("extensions.webcompat.enable_shims", true);
user_pref("extensions.webcompat.perform_injections", true);
user_pref("extensions.webcompat.perform_ua_overrides", true);
user_pref("extensions.webextensions.ExtensionStorageIDB.migrated.screenshots@mozilla.org", true);
user_pref("extensions.webextensions.uuids", "{\"formautofill@mozilla.org\":\"071680f6-9652-42d1-a002-a4823066db36\",\"pictureinpicture@mozilla.org\":\"7cb9c56d-b0fd-40b6-9d75-595b957d7e3d\",\"screenshots@mozilla.org\":\"05507440-3513-4fc5-85cb-0866dae70694\",\"webcompat-reporter@mozilla.org\":\"b8329c63-3186-4acf-818a-ce138e1ff54a\",\"webcompat@mozilla.org\":\"e376b1f1-ffdc-4084-9ba4-fa158868242d\",\"default-theme@mozilla.org\":\"ad5fbbcd-3bce-49d6-949c-f8361642f0cc\",\"addons-search-detection@mozilla.com\":\"368d957d-860d-4ad3-80bd-4698e3fb1b5d\",\"google@search.mozilla.org\":\"7ff624b8-c37e-4130-a698-067fe0c33d1f\",\"wikipedia@search.mozilla.org\":\"08b425bb-4f7a-40f6-a482-42dac0f012ea\",\"bing@search.mozilla.org\":\"5abe618c-328a-4c9a-94f2-107bc1330ba2\",\"ddg@search.mozilla.org\":\"d7e364dc-ba03-44d9-bb05-6f72275cd23c\",\"ebay@search.mozilla.org\":\"c34147bf-88d9-4e0d-b802-6344a42ea48c\",\"qwant@search.mozilla.org\":\"3379dcb4-7ed5-4730-ae81-4fbaf2a0c3b6\",\"amazon@search.mozilla.org\":\"92af764a-ab21-4482-8db2-aaa8600532ae\"}");
user_pref("gecko.handlerService.defaultHandlersVersion", 1);
user_pref("identity.fxaccounts.toolbar.defaultVisible", true);
user_pref("media.gmp.storage.version.observed", 1);
user_pref("network.http.referer.disallowCrossSiteRelaxingDefault.top_navigation", true);
user_pref("nimbus.syncdefaultsstore.fxaButtonVisibility", "{\"slug\":\"mozillaaccounts-toolbar-button-default-visibility-existing-user\",\"branch\":{\"slug\":\"treatment-a\",\"ratio\":1,\"feature\":{\"value\":null,\"enabled\":true,\"featureId\":\"fxaButtonVisibility\"},\"features\":null},\"active\":true,\"experimentType\":\"rollout\",\"source\":\"rs-loader\",\"userFacingName\":\"MozillaAccounts toolbar button default visibility rollout\",\"userFacingDescription\":\"This experiment measures the impact of showing the Firefox Accounts toolbar button by default for signed-out users.\",\"lastSeen\":\"2024-04-20T15:23:43.705Z\",\"featureIds\":[\"fxaButtonVisibility\"],\"prefs\":[{\"name\":\"identity.fxaccounts.toolbar.defaultVisible\",\"branch\":\"user\",\"featureId\":\"fxaButtonVisibility\",\"variable\":\"boolean\",\"originalValue\":null}],\"isRollout\":true}");
user_pref("nimbus.syncdefaultsstore.fxaButtonVisibility.boolean", true);
user_pref("nimbus.syncdefaultsstore.migrationWizard", "{\"slug\":\"extensions-migration-in-import-wizard-116-rollout\",\"branch\":{\"slug\":\"control\",\"ratio\":1,\"feature\":{\"value\":null,\"enabled\":true,\"featureId\":\"migrationWizard\"},\"features\":null},\"active\":true,\"experimentType\":\"rollout\",\"source\":\"rs-loader\",\"userFacingName\":\"Extensions Migration in Import Wizard - 117+\",\"userFacingDescription\":\"This rollout makes extension migration available to users migrating from Chrome to Firefox.\",\"lastSeen\":\"2024-04-20T15:23:43.680Z\",\"featureIds\":[\"migrationWizard\"],\"prefs\":[{\"name\":\"browser.migrate.content-modal.import-all.enabled\",\"branch\":\"user\",\"featureId\":\"migrationWizard\",\"variable\":\"showImportAll\",\"originalValue\":null},{\"name\":\"browser.migrate.chrome.extensions.enabled\",\"branch\":\"user\",\"featureId\":\"migrationWizard\",\"variable\":\"migrateExtensions\",\"originalValue\":null},{\"name\":\"browser.migrate.preferences-entrypoint.enabled\",\"branch\":\"user\",\"featureId\":\"migrationWizard\",\"variable\":\"showPreferencesEntrypoint\",\"originalValue\":null}],\"isRollout\":true}");
user_pref("nimbus.syncdefaultsstore.migrationWizard.migrateExtensions", true);
user_pref("nimbus.syncdefaultsstore.migrationWizard.showImportAll", true);
user_pref("nimbus.syncdefaultsstore.migrationWizard.showPreferencesEntrypoint", true);
user_pref("nimbus.syncdefaultsstore.migrationWizard.useNewWizard", true);
user_pref("nimbus.syncdefaultsstore.upgradeDialog", "{\"slug\":\"upgrade-spotlight-rollout\",\"branch\":{\"slug\":\"treatment\",\"ratio\":1,\"feature\":{\"value\":null,\"enabled\":true,\"featureId\":\"upgradeDialog\"},\"features\":null},\"active\":true,\"experimentType\":\"rollout\",\"source\":\"rs-loader\",\"userFacingName\":\"Upgrade Spotlight Rollout\",\"userFacingDescription\":\"Experimenting on onboarding content when you upgrade Firefox.\",\"lastSeen\":\"2024-04-20T15:23:43.836Z\",\"featureIds\":[\"upgradeDialog\"],\"prefs\":[],\"isRollout\":true}");
user_pref("nimbus.syncdefaultsstore.upgradeDialog.enabled", false);
user_pref("pdfjs.enabledCache.state", true);
user_pref("pdfjs.migrationVersion", 2);
user_pref("plugin.state.flash", 2);
user_pref("privacy.annotate_channels.strict_list.enabled", true);
user_pref("privacy.fingerprintingProtection", true);
user_pref("privacy.partition.network_state.ocsp_cache", true);
user_pref("privacy.query_stripping.enabled", true);
user_pref("privacy.query_stripping.enabled.pbmode", true);
user_pref("privacy.sanitize.pending", "[]");
user_pref("privacy.trackingprotection.emailtracking.enabled", true);
user_pref("privacy.trackingprotection.enabled", true);
user_pref("privacy.trackingprotection.socialtracking.enabled", true);
user_pref("security.sandbox.content.tempDirSuffix", "2eed7fc9-223a-4df4-8107-eaea7b47d7b2");
user_pref("toolkit.legacyUserProfileCustomizations.stylesheets", true);
user_pref("toolkit.startup.last_success", 1713626657);
user_pref("toolkit.telemetry.cachedClientID", "3bbab1d3-6476-42ac-807c-664db8d19677");
user_pref("toolkit.telemetry.previousBuildID", "20240118164516");
user_pref("toolkit.telemetry.reportingpolicy.firstRun", false);
